CRAN/bioconductor updater downloads tarballs twice

  • Open
  • quality assurance status badge
Details
2 participants
  • Ricardo Wurmus
  • zimoun
Owner
unassigned
Submitted by
Ricardo Wurmus
Severity
normal
Merged with
R
R
Ricardo Wurmus wrote on 2 Jun 2021 17:54
(address . bug-guix@gnu.org)
87pmx4uury.fsf@elephly.net
When upgrading packages with “guix refresh -t bioconductor -u”
Guix downloads tarballs for every package twice.

--
Ricardo
Z
Z
zimoun wrote on 9 Jun 2021 16:21
(name . Ricardo Wurmus)(address . rekado@elephly.net)(address . 48792@debbugs.gnu.org)
87bl8fjezv.fsf@gmail.com
Hi Ricardo,

On Wed, 02 Jun 2021 at 17:54, Ricardo Wurmus <rekado@elephly.net> wrote:
Toggle quote (3 lines)
> When upgrading packages with “guix refresh -t bioconductor -u” Guix downloads
> tarballs for every package twice.

It is duplicated with bug#44256, IMHO. Merge?


Cheers,
simon
Z
Z
zimoun wrote on 2 Jul 2021 18:32
control message for bug #48792
(address . control@debbugs.gnu.org)
87h7hcn0by.fsf@gmail.com
merge 48792 44256
quit
Z
Z
zimoun wrote on 4 Nov 2022 13:27
Re: bug#48792: CRAN/bioconductor updater downloads tarballs twice
(name . Ricardo Wurmus)(address . rekado@elephly.net)(address . 48792@debbugs.gnu.org)
87mt96aoqs.fsf@gmail.com
Hi,

On mer., 02 juin 2021 at 17:54, Ricardo Wurmus <rekado@elephly.net> wrote:
Toggle quote (3 lines)
> When upgrading packages with “guix refresh -t bioconductor -u” Guix downloads
> tarballs for every package twice.

It can be worse with 3 downloads.

Toggle snippet (21 lines)
$ ./pre-inst-env guix refresh -u r-rhdf5lib

Starting download of /tmp/guix-file.IjNx2z
From https://bioconductor.org/packages/release/bioc/src/contrib/Rhdf5lib_1.20.0.tar.gz...
…20.0.tar.gz 14.0MiB 96.9MiB/s 00:00 [##################] 100.0%
gnu/packages/bioconductor.scm:14362:13: r-rhdf5lib: updating from version 1.18.2 to version 1.20.0...

Starting download of /tmp/guix-file.NmqLjM
From https://bioconductor.org/packages/release/bioc/src/contrib/Rhdf5lib_1.20.0.tar.gz...
…20.0.tar.gz 14.0MiB 97.3MiB/s 00:00 [##################] 100.0%

Starting download of /tmp/guix-file.ytAuK3
From https://bioconductor.org/packages/release/bioc/src/contrib/Rhdf5lib_1.20.0.tar.gz...
…20.0.tar.gz 14.0MiB 103.3MiB/s 00:00 [##################] 100.0%
guix refresh: r-rhdf5lib: consider adding this input: zlib
gnu/packages/bioconductor.scm:14431:5: r-rhdf5lib: consider removing this native input: hdf5-source
gnu/packages/bioconductor.scm:14429:5: r-rhdf5lib: consider removing this propagated input: hdf5
gnu/packages/bioconductor.scm:14429:5: r-rhdf5lib: consider removing this propagated input: zlib


Cheers,
simon


PS: Noted when upgrading from 3.15 to 3.16 with this change.

Toggle snippet (30 lines)
diff --git a/guix/build-system/r.scm b/guix/build-system/r.scm
index 620822b870..9b360ae581 100644
--- a/guix/build-system/r.scm
+++ b/guix/build-system/r.scm
@@ -61,7 +61,7 @@ (define* (bioconductor-uri name version #:optional type)
"/src/contrib/"
name "_" version ".tar.gz")
;; TODO: use %bioconductor-version from (guix import cran)
- (string-append "https://bioconductor.org/packages/3.15"
+ (string-append "https://bioconductor.org/packages/3.16"
type-url-part
"/src/contrib/"
name "_" version ".tar.gz"))))
diff --git a/guix/import/cran.scm b/guix/import/cran.scm
index 4e1ce7c010..cdc6b806b2 100644
--- a/guix/import/cran.scm
+++ b/guix/import/cran.scm
@@ -156,9 +156,9 @@ (define %cran-url "https://cran.r-project.org/web/packages/")
(define %cran-canonical-url "https://cran.r-project.org/package=")
(define %bioconductor-url "https://bioconductor.org/packages/")

;; The latest Bioconductor release is 3.15. Bioconductor packages should be
;; updated together.
-(define %bioconductor-version "3.15")
+(define %bioconductor-version "3.16")

(define* (bioconductor-packages-list-url #:optional type)
(string-append "https://bioconductor.org/packages/"
@@ -156,9 +156,9 @@ (define %cran-url "https://cran.r-project.org/web/packages/")
(define %bioconductor-url "https://bioconductor.org/packages/")

-;; The latest Bioconductor release is 3.15. Bioconductor packages should be
+;; The latest Bioconductor release is 3.16. Bioconductor packages should be
;; updated together.
?